@@ -171,7 +171,7 @@ def preSympifySub(expr,**kwargs):
 
     # Check if any function listed is present in expr
     for func in func_list:
-        if func in expr:
+        if func in str(expr):
             func_pres.append(1)
         else:
             func_pres.append(0)
@@ -192,10 +192,115 @@ def preSympifySub(expr,**kwargs):
             expr = sub(regex,rf"({str(v)})",str(expr))
     return expr
 
-if __name__ == "__main__":
-    expr = 'eq.append("Eq(w,integrate(C*v,(v,v0,v1))-integrate(C*v,(v,v0,v1))+integrate(8*diff(v**2,v),(v,v0,vt), (v4,f3)))")'
-    
+# def Capacitance(find="C", printEq=False, **kwargs):
+#     """
+#     Usage: the ratio of the charge on one plate of a capacitor to the voltage difference between the two plates, measured in farads (F).
 
-    print(expr, "\n")
-    expr2 = preSympifySub(expr,v="99*red_ballons")
-    print(expr2)
\ No newline at end of file
+#     Variables: 
+#                 C = capacitance (1 Farads = 1 Coulomb/Volt)
+#                 epsilon = permitivity of the dielectric material between plates
+#                 A = surface area of each plate
+#                 d = distance between plates"""
+#     eq = list()
+#     eq.append("Eq(C,epsilon*A/d)")    
+#     return solveEqs(eq, find, printEq=printEq, **kwargs)
+
+# def solveEqs(eq, find, printEq=False, **kwargs):
+#     """
+#     Solves multiple equations independently in search for variable.
+#     Allows substitution via kwargs.
+#     In other words, algebraSolve() on multiple equations at once.
+
+#     Usage:
+#         eq = list()
+#         eq.append("Eq(a_tan, dv/dt)")
+#         eq.append("Eq(a_tan, r*dw/dt)")
+#         eq.append("Eq(a_tan, r*alpha)")
+#         solveEqs(eq, "a_tan", printEq=printEq, **kwargs)
+
+#     Returns:
+#         [
+#             ans1,
+#             ans2,
+#             ans3
+#         ]
+#     """
+#     #CREATE SET OF ARGUMENTS SUPPLIED TO FUNCTION
+#     availSet = {find}
+#     for k,v in kwargs.items():
+#         availSet.add(k)
+#         v=str(v)
+#     eq = [preSympifySub(expr,**kwargs) for expr in eq]
+#     eq = [sympify(expr) for expr in eq]
+#     freesym = [expr.free_symbols for expr in eq]
+#     freevar = []
+#     solution = list()
+#     #CONVERT LIST OF SETS OF SYMBOLS INTO LIST OF SETS OF STR
+#     for freeset in freesym:
+#         tempset = set()
+#         for sym in freeset:
+#             tempset.add(sym.name)
+#         freevar.append(tempset)
+#     unknowns = [freeset-availSet for freeset in freevar]            # Eliminate variables requested in function arguments: find and knowns
+#     unknowns_count = [len(unknownset) for unknownset in unknowns]   # How many unknowns are left in each equation?
+#     find_avail = [find in freevarset for freevarset in freevar]     # Is the variable in question available in this equation?
+#     index = list(range(len(unknowns_count)))
+#     zipper = list(zip(index, unknowns_count, find_avail))
+
+#     for zippedList in zipper:
+#         solution.append(algebraSolve(eq[zippedList[0]],find, **kwargs))
+
+#     printEquationsSolution(eq, solution) #print Equations and Solutions to console
+#     return solution
+
+# def printEquations(eq):
+#     # print("Equations:\n")
+#     for equation in eq:
+#         print(equation)
+
+# def printEquationsSolution(eq, solution, printEq=True):
+#     #if printEq:
+#     print("\n")
+#     print("Equations"), printEquations(eq), print("\n")
+#     print("Solutions"), printEquations(solution), print("\n")
+
+# def algebraSolve(expr, solve_for,**kwargs):
+#     """
+#     Solves single algebraic string equation. 
+    
+#     Usage: algebraSolve("x**2 + 3*x - 1/2 + y", "x", y=24)
+
+#     Returns: [ans]
+#     """
+#     expr = preSympifySub(expr,**kwargs)
+#     expr=sympify(expr)
+#     #GENERATE VARIABLE SYMBOLS FROM EXPRESSION
+#     for sym in expr.free_symbols: 
+#         exec(f"{sym.name}=symbols('{sym.name}')")
+#         #MAKE solve_for STRING EQUAL REQUIRED EXPRESSION VARIABLE SYMBOL
+#         if solve_for == sym.name:    
+#             solve_for = sym
+        
+#         # SUBSTITUTE KARGs FOR EXPRESSION SYMBOLS
+#         for k, v in kwargs.items():
+#             if k == sym.name:
+#                 expr=expr.subs(k,v)
+#     return solve(expr, solve_for)
+
+if __name__ == "__main__":
+    pass
+    # expr = 'eq.append("Eq(w,integrate(C*v,(v,v0,v1))-integrate(C*v,(v,v0,v1))+integrate(8*diff(v**2,v),(v,v0,vt), (v4,f3)))")'
+    
+    # print(expr, "\n")
+    # expr2 = preSympifySub(expr,v="99*red_ballons")
+    # print(expr2) 
+    
+    # import grtoolkit.Circuits as c 
+    # c.Capacitors.Capacitance("C", 
+    #                         epsilon=48,
+    #                         A = 89,
+    #                         d = 79) 
+    # from grtoolkit.Math import solveEqs
+
+    # from sympy import sympify, solve, symbols
+    # Capacitance("C", epsilon=49, A=56, d=79)
\ No newline at end of file
